@@ -1,8 +1,8 @@
 <?php
-// $Id: ezmlm.php,v 1.4.12.1 2004/04/07 09:16:14 turbo Exp $
+// $Id: ezmlm.php,v 1.6 2005/02/24 17:04:00 turbo Exp $
 //
 require("./include/pql_config.inc");
-include("./header.html");
+include($_SESSION["path"]."/header.html");
 ?>  
   <span class="title1">Ezmlm Mailinglist Control</span>
 
